@@ -1,11 +1,10 @@
 # This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild
 
-from pkg_resources import parse_version
 import kaitaistruct
 from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO
 
 
-if parse_version(kaitaistruct.__version__) < parse_version("0.9"):
+if getattr(kaitaistruct, "API_VERSION", (0, 9)) < (0, 9):
     raise Exception(
         "Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s"
         % (kaitaistruct.__version__)
@@ -33,7 +32,7 @@ class Gpsdata(KaitaiStruct):
     @property
     def gps_available(self):
         if hasattr(self, "_m_gps_available"):
-            return self._m_gps_available if hasattr(self, "_m_gps_available") else None
+            return self._m_gps_available
 
         self._m_gps_available = (self.gps_status).decode("ASCII") == "A"
-        return self._m_gps_available if hasattr(self, "_m_gps_available") else None
+        return getattr(self, "_m_gps_available", None)
