@@ -1,11 +1,10 @@
 # This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild
 
-from pkg_resources import parse_version
 import kaitaistruct
 from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO
 
 
-if parse_version(kaitaistruct.__version__) < parse_version("0.9"):
+if getattr(kaitaistruct, "API_VERSION", (0, 9)) < (0, 9):
     raise Exception(
         "Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s"
         % (kaitaistruct.__version__)
@@ -33,9 +32,19 @@ class RadioIp(KaitaiStruct):
     @property
     def radio_id(self):
         if hasattr(self, "_m_radio_id"):
-            return self._m_radio_id if hasattr(self, "_m_radio_id") else None
+            return self._m_radio_id
 
         self._m_radio_id = (
+            (self.radio_id_1 * 10000) + (self.radio_id_2 * 100)
+        ) + self.radio_id_3
+        return getattr(self, "_m_radio_id", None)
+
+    @property
+    def radio_id_str(self):
+        if hasattr(self, "_m_radio_id_str"):
+            return self._m_radio_id_str
+
+        self._m_radio_id_str = (
             str(self.radio_id_1) + str(self.radio_id_2) + str(self.radio_id_3)
         )
-        return self._m_radio_id if hasattr(self, "_m_radio_id") else None
+        return getattr(self, "_m_radio_id_str", None)
